awali: Computation of/with finite state machines
================================================

Description
-----------

Awali is a software platform dedicated to the computation of, and with,
finite state machines. Here finite state machines is to be understood in
the broadest possible sense: finite automata with output — often called
transducers then — or even more generally finite automata with
multiplicity, that is, automata that not only accept, or recognize,
sequences of symbols but compute for every such sequence a 'value' that
is associated with it and which can be taken in any semiring. Hence the
variety of situations that can thus be modellized.

License
-------

-  GPL 3.0


Upstream Contact
----------------

-  Website: http://vaucanson-project.org/Awali/index.html
-  Releases: http://files.vaucanson-project.org/tarballs/

Dependencies
------------

-  graphviz must be installed from your distro, and available in the
   path.
